History
=======

0.0.5 (2023-11-17)
--------------------
* Misc bugfixes and improvements;

0.0.3 (2023-11-03)
--------------------
* Many algorithmic improvements (including mro patching);
* IPyflow integrations;

0.0.2 (2023-10-02)
--------------------
* Initial unadvertised prerelease with basic read-only patching working X-platform;

0.0.1 (2023-03-25)
--------------------
* Initial package squat release of superduperreload;
